@@ -63,12 +63,12 @@ public:
   void setEnabled(bool enabled) { enabled_ = enabled; }
   // Float value between 0 and 1 of "how enabled" we are as we are
   // ramping between disabled/enabled state.
-  float enabledRatio() { return enabled_ratio_; }
+  double enabledRatio() { return enabled_ratio_; }
   // Set how fast we ramp between enabled and disabled states; returns "false"
   // if value given is invalid.
-  bool setRampTime(float ramp_time);
+  bool setRampTime(double ramp_time);
   // How fast we ramp between enabled and disabled states
-  float rampTime() { return ramp_time_; }
+  double rampTime() { return ramp_time_; }
 
   // Callback which updates state on the arm. Invoked by Arm::update.
   // Returns `true` on success and `false` otherwise.
@@ -120,11 +120,11 @@ private:
   // Name of the plugin
   const std::string name_{};
   // How long it takes to fully transition enabled state.
-  float ramp_time_{};
+  double ramp_time_{};
   // Whether the plugin is enabled
   bool enabled_{true};
   // Current linear level between off (0) and on (1); updated during `update`
-  float enabled_ratio_{1.f};
+  double enabled_ratio_{1.};
 };
 
 using Factory = std::function<std::unique_ptr<Plugin>(const PluginConfig&)>;
@@ -318,14 +318,15 @@ public:
   // Setup functions
   //////////////////////////////////////////////////////////////////////////////
 
-  // Parameters for creating an arm
+  // Parameters for creating an arm.
+  // Note this structure is deprecated in favor of using HEBI robot config files.
   struct Params {
     // The family and names passed to the "lookup" function to find modules
     // Both are required.
     std::vector<std::string> families_;
     std::vector<std::string> names_;
-    // How long a command takes effect for on the robot before expiring.
-    int command_lifetime_ = 100;
+    // How long a command takes effect for on the robot before expiring, in ms.
+    int32_t command_lifetime_ = 100;
     // Loop rate, in Hz.  This is how fast the arm update loop will nominally
     // run.
     double control_frequency_ = 200.f;
@@ -410,6 +411,12 @@ public:
   // using the arm may result in undefined behavior.
   robot_model::RobotModel& robotModel() { return *robot_model_; }
 
+  // Returns the velocity limits used for trajectory generation.
+  const Eigen::VectorXd& velocityLimits() const { return vel_limits_; }
+
+  // Returns the acceleration limits used for trajectory generation.
+  const Eigen::VectorXd& accelerationLimits() const { return accel_limits_; }
+
   // Returns the currently active internal trajectory. Not necessary for most
   // use cases.
   // Returns 'nullptr' if there is no active trajectory.
@@ -583,6 +590,36 @@ public:
     return kinematics_helper_.solveIK6Dof(*robot_model_, initial_positions, target_xyz, orientation);
   }
 
+  //////////////////////////////////////////////////////////////////////////////
+  // Helper functions for velocity and acceleration limits used in setGoal
+  //////////////////////////////////////////////////////////////////////////////
+
+  void setVelocityLimits(const Eigen::VectorXd& vel_limits) {
+    if (static_cast<size_t>(vel_limits.size()) != size())
+      throw std::invalid_argument("Velocity limits size does not match robot DoF count.");
+    vel_limits_ = vel_limits;
+  }
+
+  void setVelocityLimitsFromModel() {
+    robot_model_->getMaxSpeeds(vel_limits_);
+  }
+
+  void clearVelocityLimits() {
+    // Set limits to infinity (no limits)
+    vel_limits_ = Eigen::VectorXd::Constant(size(), std::numeric_limits<double>::infinity());
+  }
+
+  void setAccelerationLimits(const Eigen::VectorXd& accel_limits) {
+    if (static_cast<size_t>(accel_limits.size()) != size())
+      throw std::invalid_argument("Acceleration limits size does not match robot DoF count.");
+    accel_limits_ = accel_limits;
+  }
+
+  void clearAccelerationLimits() {
+    // Set limits to infinity (no limits)
+    accel_limits_ = Eigen::VectorXd::Constant(size(), std::numeric_limits<double>::infinity());
+  }
+
 private:
   // Private arm constructor
   Arm(std::function<double()> get_current_time_s, std::shared_ptr<Group> group,
@@ -595,8 +632,13 @@ private:
       pos_(Eigen::VectorXd::Zero(group_->size())),
       vel_(Eigen::VectorXd::Zero(group_->size())),
       accel_(Eigen::VectorXd::Zero(group_->size())),
+      vel_limits_(Eigen::VectorXd::Constant(group_->size(), std::numeric_limits<double>::infinity())),
+      accel_limits_(Eigen::VectorXd::Constant(group_->size(), std::numeric_limits<double>::infinity())),
       feedback_(group_->size()),
-      command_(group_->size()) {}
+      command_(group_->size()) {
+        // Set velocity limit from robot model
+        setVelocityLimitsFromModel();
+      }
 
   // Optionally uses lookup object internally
   static std::unique_ptr<Arm> create(const RobotConfig& config, const Lookup* lookup);
@@ -629,6 +671,10 @@ private:
   // Robot model helpers for FK + IK
   internal::KinematicsHelper kinematics_helper_;
 
+  // Velocity and acceleration limits for trajectory generation
+  Eigen::VectorXd vel_limits_;
+  Eigen::VectorXd accel_limits_;
+
   hebi::GroupFeedback feedback_;
   hebi::GroupCommand command_;
 
